package com.javahonk.service;

import java.io.IOException;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.ws.rs.HttpMethod;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.eclipse.jetty.server.Request;
import org.eclipse.jetty.server.handler.AbstractHandler;

import com.javahonk.adapter.ServerMessageProcessor;

public class MessageHandler extends AbstractHandler {

    private static final Logger logger = LogManager.getLogger(MessageHandler.class.getName());

    @Resource(name="urlToAdaptorMap")
    Map<String, ServerMessageProcessor> urlToAdaptorMap;


    public void handle(String target, Request baseRequest,
                       HttpServletRequest request, HttpServletResponse response)
            throws IOException, ServletException {

        logger.info("HTTP remote box- " + request.getRemoteAddr());
        logger.info("HTTP request- " + request.getPathInfo());

        String path = request.getPathInfo();

        if (request.getMethod().equals(HttpMethod.POST)) {
            try {
                if (urlToAdaptorMap.containsKey(path)) {
                    urlToAdaptorMap.get(path).handleRequest(request, response);
                    response.setStatus(HttpServletResponse.SC_OK);
                }
                baseRequest.setHandled(true);
            } catch (Exception ex) {
                logger.error("Error :", ex);
                response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
            }
        } else {
            logger.warn("Received request on unsupported url {}", path);
            response.setStatus(HttpServletResponse.SC_SERVICE_UNAVAILABLE);
        }
    }
}